pycocoa.panels.ErrorPanel

Package pycocoa :: Module panels :: Class ErrorPanel |
[frames] | no frames]

# Class ErrorPanel

      object --+
               |
    bases._Type0 --+
                   |
        bases._Type1 --+
                       |
            bases._Type2 --+
                           |
                  AlertPanel --+
                               |
                              ErrorPanel

Python Type to show an `NSError` alert, wrapping ObjC `NSAlert`.

Instance Methods
__init__(self, title=`'``Error``'`) New AlertPanel. |
show(self, ns_error, timeout=None) Show the error. |
Inherited from `bases._Type2`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `bases._Type2`: `title` Inherited from `bases._Type1`: `NSdelegate`, `app` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __init__(self, title=`'``Error``'`) (Constructor) |
New AlertPanel. Parameters: `title` - The panel name and title (`str`). Raises: `ValueError` - Multi-line info or too long. Overrides: object.__init__

### show(self, ns_error, timeout=None) |
Show the error. Parameters: `ns_error` - Error information (`NSError`). `timeout` - Optional time limit (`float`). Returns: TBD. Raises: `TypeError` - Invalid ns_error. Overrides: AlertPanel.show